package com.songhua.system.mapper;

import java.util.List;
import com.songhua.system.domain.BasicCruiseShip;

/**
 * 游船Mapper接口
 * 
 * @author ruoyi
 * @date 2024-04-23
 */
public interface BasicCruiseShipMapper 
{
    /**
     * 查询游船
     * 
     * @param id 游船主键
     * @return 游船
     */
    public BasicCruiseShip selectBasicCruiseShipById(Long id);

    /**
     * 查询游船列表
     * 
     * @param basicCruiseShip 游船
     * @return 游船集合
     */
    public List<BasicCruiseShip> selectBasicCruiseShipList(BasicCruiseShip basicCruiseShip);

    /**
     * 新增游船
     * 
     * @param basicCruiseShip 游船
     * @return 结果
     */
    public int insertBasicCruiseShip(BasicCruiseShip basicCruiseShip);

    /**
     * 修改游船
     * 
     * @param basicCruiseShip 游船
     * @return 结果
     */
    public int updateBasicCruiseShip(BasicCruiseShip basicCruiseShip);

    /**
     * 删除游船
     * 
     * @param id 游船主键
     * @return 结果
     */
    public int deleteBasicCruiseShipById(Long id);

    /**
     * 批量删除游船
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasicCruiseShipByIds(Long[] ids);

    public List<Long> selectDidList();
}
